@@ -10,16 +10,16 @@
 #' @return A table that can be more easily mapped and used
 #' for summary plots.
 #'
-#' @keywords Internal
+#' @keywords internal
 #'
 #' @examples
 #' data(myOccCiteObject)
 #' tabulate.occResults(myOccCiteObject@occResults,
 #'   sp.name = "Protea cynaroides"
 #' )
-#' @importFrom dplyr "%>%" filter
+#' @importFrom dplyr "%>%" mutate_if mutate bind_rows
 #'
-#' @export
+#' @noRd
 
 tabulate.occResults <- function(x, sp.name) {
   sp.name <- stringr::str_extract(
@@ -30,10 +30,10 @@ tabulate.occResults <- function(x, sp.name) {
   occTbls.nulls <- sapply(occTbls, is.null)
   occTbls.char <- lapply(occTbls[!occTbls.nulls], function(tbl) {
     tbl %>%
-      dplyr::mutate_if(is.factor, as.character) %>%
-      dplyr::mutate(name = sp.name)
+      mutate_if(is.factor, as.character) %>%
+      mutate(name = sp.name)
   })
-  occTbls.bind <- dplyr::bind_rows(occTbls.char)
+  occTbls.bind <- bind_rows(occTbls.char)
   return(occTbls.bind)
 }
 
@@ -80,12 +80,16 @@ tabulate.occResults <- function(x, sp.name) {
 #' @return A leaflet map
 #'
 #' @examples
+#' \dontrun{
 #' data(myOccCiteObject)
 #' occCiteMap(myOccCiteObject, cluster = FALSE)
+#' }
+#'
 #' @importFrom dplyr "%>%" filter
 #' @importFrom rlang .data
 #' @importFrom stats complete.cases
 #' @importFrom RColorBrewer brewer.pal
+#' @import leaflet
 #'
 #' @export
 #'
@@ -127,12 +131,17 @@ occCiteMap <- function(occCiteData,
 
   if (!is.null(species_colors)) {
     if (length(species_colors) != length(sp.names)) {
-      stop(paste0("Number of species colors provided must\n",
-                  "match number of species mapped."))
+      stop(paste0(
+        "Number of species colors provided must\n",
+        "match number of species mapped."
+      ))
     }
-    if (awesomeMarkers == TRUE & !all(species_colors %in% awesomeMarkers.cols)) {
-      stop(paste0("If mapping awesomeMarkers, please specify species\n",
-                  "colors from those available (see Details in ?occCiteMap)"))
+    if (awesomeMarkers == TRUE & !all(species_colors %in%
+      awesomeMarkers.cols)) {
+      stop(paste0(
+        "If mapping awesomeMarkers, please specify species\n",
+        "colors from those available (see Details in ?occCiteMap)"
+      ))
     }
   }
 
@@ -141,10 +150,14 @@ occCiteMap <- function(occCiteData,
     function(x) tabulate.occResults(d.res[[x]], names(d.res)[x])
   )
   for (i in 1:length(d.tbl)) {
-    if (nrow(d.tbl[[i]]) > 0){
-      d.tbl[[i]] <- d.tbl[[i]][complete.cases(d.tbl[[1]][,
-                                                         c("longitude",
-                                                           "latitude")]), ]
+    if (nrow(d.tbl[[i]]) > 0) {
+      d.tbl[[i]] <- d.tbl[[i]][complete.cases(d.tbl[[1]][
+        ,
+        c(
+          "longitude",
+          "latitude"
+        )
+      ]), ]
     }
     d.tbl.n <- nrow(d.tbl[[i]])
     if (d.tbl.n > map_limit) {
@@ -235,7 +248,8 @@ occCiteMap <- function(occCiteData,
     clusterOpts <- NULL
   }
 
-  m <- leaflet::leaflet() %>% leaflet::addProviderTiles(leaflet::providers$Esri.WorldPhysical)
+  m <- leaflet::leaflet() %>%
+    leaflet::addProviderTiles(leaflet::providers$Esri.WorldPhysical)
 
   if (awesomeMarkers == TRUE) {
     makeIconList <- function(sp) {
@@ -334,10 +348,12 @@ occCiteMap <- function(occCiteData,
 plot.occCiteData <- function(x, ...) {
   # Function to wrap labels
   occ_strwrap <- function(x) {
-    x <- unlist(lapply(strwrap(x, width = 30, simplify= FALSE),
-                  paste, collapse = "\n"))
+    x <- unlist(lapply(strwrap(x, width = 30, simplify = FALSE),
+      paste,
+      collapse = "\n"
+    ))
     return(x)
-    }
+  }
 
   args <- list(...)
 
@@ -373,8 +389,7 @@ plot.occCiteData <- function(x, ...) {
       plotTypes[!plotTypes %in% plots]
     ))
     return(NULL)
-  }
-  else if (is.null(plotTypes)) { # Fills in NULL
+  } else if (is.null(plotTypes)) { # Fills in NULL
     plotTypes <- plots
   }
 
@@ -384,9 +399,13 @@ plot.occCiteData <- function(x, ...) {
     function(x) tabulate.occResults(d.res[[x]], names(d.res)[x])
   )
   for (i in 1:length(d.tbl)) {
-    d.tbl[[i]] <- d.tbl[[i]][complete.cases(d.tbl[[1]][,
-                                                       c("longitude",
-                                                         "latitude")]), ]
+    d.tbl[[i]] <- d.tbl[[i]][complete.cases(d.tbl[[1]][
+      ,
+      c(
+        "longitude",
+        "latitude"
+      )
+    ]), ]
     d.tbl.n <- nrow(d.tbl[[i]])
     if (d.tbl.n == 0) {
       d.tbl[[i]] <- NULL
@@ -442,8 +461,7 @@ plot.occCiteData <- function(x, ...) {
           title = "All Occurrence Records by Primary Data Source",
           xlab = "*Sources contributing <2% not shown."
         )
-      }
-      else {
+      } else {
         source <- waffle::waffle(pct,
           rows = 10,
           colors = viridis::viridis(length(pct)),
@@ -453,8 +471,7 @@ plot.occCiteData <- function(x, ...) {
       source <- ggplot_build(source)
       if ("yearHistogram" %in% plotTypes) {
         allPlots[[2]] <- source
-      }
-      else {
+      } else {
         allPlots[[1]] <- source
       }
     }
@@ -475,8 +492,7 @@ plot.occCiteData <- function(x, ...) {
     }
     names(allPlots) <- plotTypes
     return(allPlots)
-  }
-  else {
+  } else {
     spList <- unique(d$name)
     spList <- spList[!is.na(spList)]
     spPlotList <- vector(mode = "list", length = length(spList))
@@ -521,8 +537,7 @@ plot.occCiteData <- function(x, ...) {
             title = paste0(sp, " Occurrence Records by Primary Data Source"),
             xlab = "*Sources contributing <2% not shown."
           )
-        }
-        else {
+        } else {
           source <- waffle::waffle(pct,
             rows = 10,
             colors = viridis::viridis(length(pct)),
@@ -535,8 +550,7 @@ plot.occCiteData <- function(x, ...) {
         source <- ggplot_build(source)
         if ("yearHistogram" %in% plotTypes) {
           allPlots[[2]] <- source
-        }
-        else {
+        } else {
           allPlots[[1]] <- source
         }
       }
